//--------------------------------------------------------------
// File     : main.c
// Datum    : 10.05.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// Board    : STM32F429-Board von UB (Version 1.0)
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Hauptprogramm
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------
// Beschreibung :
// LoLevel-Test vom eigenbau STM32F429-Board von UB (Version 1.0)
//
// test vom externen SPI-Flash auf dem STM32F429-Board
//
// Statusausgabe per COM-6 (3,3V UART) 115200 Baud
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_systick.h"
#include "stm32_ub_uart.h"
#include "stm32_ub_sst25vf016.h"
#include <stdio.h>



int main(void)
{
  ErrorStatus check;
  uint8_t wert;
  char buf[50];


  SystemInit(); // Quarz Einstellungen aktivieren

  // init vom sytsick
  UB_Systick_Init();

  // init der uart
  UB_Uart_Init();

  // powerOn string
  UB_Uart_SendString(COM6,"F429-Board",CRLF);
  UB_Uart_SendString(COM6,"SPI-Flash-Check",CRLF);

  // check ob SPI-Flash ok
  check=UB_SST25VF016_Init();
  if(check==SUCCESS) {
    UB_Uart_SendString(COM6,"Flash ok",CRLF);

    // lesen von zwei Adressen
    wert=UB_SST25VF016_ReadByte(0x123);
    sprintf(buf,"read Adr 0x123 : %x[h]",wert);
    UB_Uart_SendString(COM6,buf,CRLF);
    wert=UB_SST25VF016_ReadByte(0x234);
    sprintf(buf,"read Adr 0x234 : %x[h]",wert);
    UB_Uart_SendString(COM6,buf,CRLF);

    // schreibschutz aufheben
    UB_SST25VF016_SetProtectionLevel(0);

    // schreiben von zwei Adressen
    UB_SST25VF016_WriteByte(0x123,0x5A);
    UB_Uart_SendString(COM6,"write Adr 0x123 : 5A[h]",CRLF);
    UB_SST25VF016_WriteByte(0x234,0x81);
    UB_Uart_SendString(COM6,"write Adr 0x234 : 81[h]",CRLF);
  }
  else {
    UB_Uart_SendString(COM6,"Flash error",CRLF);
  }

  while(1)
  {

  }
}

