//--------------------------------------------------------------
// File     : stm32_ub_sstvf016.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_SSTVF016_H
#define __STM32F4_UB_SSTVF016_H

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32_ub_spi5.h"




//--------------------------------------------------------------
// SPI Chip-Select-Pin
//--------------------------------------------------------------
#define SST25VF016_CS_PIN             GPIO_Pin_11
#define SST25VF016_CS_GPIO_PORT       GPIOI
#define SST25VF016_CS_GPIO_CLK        RCC_AHB1Periph_GPIOI



//--------------------------------------------------------------
// MAX Adresse vom Flash
//--------------------------------------------------------------
#define  SST25VF016_SIZE   0x200000  // 2MByte


//--------------------------------------------------------------
// Status-Register Bits
//--------------------------------------------------------------
#define  SST25VF016_BUSY_BIT   0x01 // 1=busy
#define  SST25VF016_BP0_BIT    0x04 // 1=lock
#define  SST25VF016_BP1_BIT    0x08 // 1=lock
#define  SST25VF016_BP2_BIT    0x10 // 1=lock


//--------------------------------------------------------------
// CMD-Nummern
//--------------------------------------------------------------
#define  SST25VF016_WSR_CMD    0x01  // Write Status Register
#define  SST25VF016_WB_CMD     0x02  // Write Byte
#define  SST25VF016_RB_CMD     0x03  // Read Byte
#define  SST25VF016_WD_CMD     0x04  // Write disable
#define  SST25VF016_RSR_CMD    0x05  // Read Status Register
#define  SST25VF016_WE_CMD     0x06  // Write enable
#define  SST25VF016_CLRALL_CMD 0x60  // Chip Erase
#define  SST25VF016_RID_CMD    0x90  // Read ID
#define  SST25VF016_WW_CMD     0xAD  // Write Word (auto increment)



//--------------------------------------------------------------
// ID-Nummern
//--------------------------------------------------------------
#define   SST25VF016_MAN_ID  0xBF // SST
#define   SST25VF016_DEV_ID  0x41 // 25VF016B



//--------------------------------------------------------------
#define  SST25VF016_SPI_PAUSE  10



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_SST25VF016_Init(void);
uint8_t UB_SST25VF016_GetProtectionLevel(void);
void UB_SST25VF016_SetProtectionLevel(uint8_t mode);
void UB_SST25VF016_EraseFlash(void);
uint8_t UB_SST25VF016_ReadByte(uint32_t adr);
void UB_SST25VF016_WriteByte(uint32_t adr, uint8_t value);
void UB_SST25VF016_ReadBlock(uint8_t* ptrBuffer, uint32_t startAdr, uint32_t lenBuffer);
void UB_SST25VF016_WriteBlock(uint8_t* ptrBuffer, uint32_t startAdr, uint32_t lenBuffer);




//--------------------------------------------------------------
#endif // __STM32F4_UB_SSTVF016_H
